@@ -119,7 +119,7 @@ main (int argc, char *argv[])
       return EXIT_FAILURE;
     }
 
-  stage = clutter_stage_get_default ();
+  stage = clutter_stage_new ();
   clutter_actor_set_size (CLUTTER_ACTOR(stage), 320.0f, 240.0f);
 
   /* We need to set certain props on the target texture currently for
@@ -155,9 +155,9 @@ main (int argc, char *argv[])
     g_critical("Could not link elements");
   gst_element_set_state (GST_ELEMENT(pipeline), GST_STATE_PLAYING);
 
-  clutter_group_add (CLUTTER_GROUP (stage), texture);
+  clutter_actor_add_child (stage, texture);
   /* clutter_actor_set_opacity (texture, 0x11); */
-  clutter_actor_show_all (stage);
+  clutter_actor_show (stage);
 
   clutter_main();
 
